"""
Django base settings for django project.
"""
import os

from django.utils.translation import ugettext_lazy as _


# WARNING: only used on development environment!
SECRET_KEY = '-kll-u!+nvn&4&jf1osp79*6-1-ikoz3)0ogq=u++ox%_+lu2w'


# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

PROJECT_DIR = os.path.join(BASE_DIR, '..')

# default project name
PROJ_NAME = os.environ.setdefault('PROJ_NAME', 'evoteanonymizer')


ALLOWED_HOSTS = ['*']

ADMINS = [('Dev', 'dev-errors@eurotux.com')]


# Application definition

INSTALLED_APPS = [
    # django apps
    'django.contrib.contenttypes',
    'django.contrib.staticfiles',

    # external apps
    'rest_framework',
    'rest_framework_swagger',

    # custom apps
    'core'
]

MIDDLEWARE_CLASSES = [
    'django.middleware.security.SecurityMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = '{}.urls'.format(PROJ_NAME)

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [
            os.path.join(PROJECT_DIR, 'templates'),
        ],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.contrib.auth.context_processors.auth',
                'django.template.context_processors.debug',
                'django.template.context_processors.i18n',
                'django.template.context_processors.media',
                'django.template.context_processors.static',
                'django.template.context_processors.request',
                'django.template.context_processors.csrf',
                'django.template.context_processors.tz',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = '{}.wsgi.application'.format(PROJ_NAME)


# Internationalization
# https://docs.djangoproject.com/en/1.9/topics/i18n/

LANGUAGES = (
    ('en', _('English')),
    ('pt', _('Portuguese')),
)

LANGUAGE_CODE = 'pt'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.9/howto/static-files/

STATIC_ROOT = os.path.join(PROJECT_DIR, '../data/static')
STATIC_URL = '/static/'
STATICFILES_DIRS = [
    os.path.join(PROJECT_DIR, "static"),
]
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
)


# DRF Settings
REST_FRAMEWORK = {
    'UNAUTHENTICATED_USER': None,
    'UNICODE_JSON': False
}


# Anonymizer service settings

EVOTE_SHUFFLE_MULTIPLIER = 3
EVOTE_OPTIMIZED_INSERT = True
